==> yudit_1.1.orig.tar.gz: yudit-1.1/src/UString.h <==
//  UString.h version 1.1
//  yudit package - Unicode Editor for the X Window System (and Linux) 
//
//  Author: gsinai@iname.com (Gaspar Sinai)
//  GNU Copyright (C) 1997,1998  Gaspar Sinai
// 
//  yudit version 1.1  Copyright(C) 23 August,   1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.0  Copyright(C) 17 May,      1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.99 Copyright(C)  4 April,    1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.97 Copyright(C)  4 February, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.95 Copyright(C) 10 January,  1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.94 Copyright(C) 17 December, 1997, Tokyo Japan  Gaspar Sinai
//  yudit version 0.9 Copyright (C)  8 December, 1997, Tokyo Japan  Gaspar Sinai
//  yutex version 0.8 Copyright (C)  5 November, 1997, Tokyo Japan  Gaspar Sinai
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//
// Gaspar Sinai 3 September 1997
//

#ifndef __ustring_h__
#define __ustring_h__

#include <UMap.h>
#include <UCS2Conv.h>


//
//
//
class UString
{
public:
	enum UStatus		{OK, ERROR};

				~UString ();
				UString ();
				UString (const unsigned char* string);
				UString (const unsigned char* string, 
					const char* converter);
				UString (const UCS2* string);

				UString (UCS2Converter* converterIn,
					const char* converterName);

	unsigned char*		getString ();
	UCS2*			getUString ();
	void			putString (const unsigned char* str);
	void			putUString (const UCS2* str);
	UStatus			setConverter (const char* nameConverter);

	inline const char*	getConverter () const { return converterName; }

	operator 		const UCS2* () const;
protected:
	UCS2			*string;

	UCS2*			decode (const unsigned char* string);
	unsigned char*		encode (const UCS2* string);
	UStatus			addConverter (UCS2Converter* converterIn, 
					const char* nameConverter);
	int			size (const UCS2* string) const;

private:
	UCS2Converter* 		converter;
	char*			converterName;
};

#endif /* __ustring_h__ */

==> yudit_1.5.orig.tar.gz: yudit-1.5/src/UString.h <==
//  UString.h version 1.5
//  yudit package - Unicode Editor for the X Window System (and Linux) 
//
//  Author: gsinai@iname.com (Gaspar Sinai)
//  GNU Copyright (C) 1997,1998,1999  Gaspar Sinai
// 
//  yudit version 1.5  Copyright(C) 30 November, 1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.4  Copyright(C) 25 November, 1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.3  Copyright(C)  5 April,    1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.2  Copyright(C) 10 December, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.1  Copyright(C) 23 August,   1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.0  Copyright(C) 17 May,      1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.99 Copyright(C)  4 April,    1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.97 Copyright(C)  4 February, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.95 Copyright(C) 10 January,  1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.94 Copyright(C) 17 December, 1997, Tokyo Japan  Gaspar Sinai
//  yudit version 0.9 Copyright (C)  8 December, 1997, Tokyo Japan  Gaspar Sinai
//  yutex version 0.8 Copyright (C)  5 November, 1997, Tokyo Japan  Gaspar Sinai
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//
// Gaspar Sinai 3 September 1997
//

#ifndef __ustring_h__
#define __ustring_h__

#include <UMap.h>
#include <UCS2Conv.h>


//
//
//
class UString
{
public:
	enum UStatus		{OK, ERROR};

				~UString ();
				UString ();
				UString (const unsigned char* string,
					const int length=-1);
				UString (const unsigned char* string, 
					const char* converter,
					const int length=-1);
				UString (const UCS2* string, const int length);

				UString (UCS2Converter* converterIn,
					const char* converterName);

	unsigned char*		getString (int* retSize);
	UCS2*			getUString (int* retSize);
	void			putString (const unsigned char* str, const int length=-1);
	void			putUString (const UCS2* str, const int length);
	UStatus			setConverter (const char* nameConverter);

	inline const char*	getConverter () const { return converterName; }

protected:
	UCS2			*string;
	int			stringSize;

	UCS2*			decode (const unsigned char* string, const int _length, int* retSize);
	unsigned char*		encode (const UCS2* string, const int length, int* retSize);
	UStatus			addConverter (UCS2Converter* converterIn, 
					const char* nameConverter);
private:
	UCS2Converter* 		converter;
	char*			converterName;
};

#endif /* __ustring_h__ */
